var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  createSvelteNodeView: () => createSvelteNodeView,
  svelteNodeViewPlugin: () => svelteNodeViewPlugin,
  svelteSchemaNode: () => svelteSchemaNode
});
module.exports = __toCommonJS(src_exports);

// src/nodeview.ts
function supressMissingPropWarnings(props, fn) {
  const re = new RegExp(`was created with unknown prop '(${Object.keys(props).join("|")})'`);
  const _warn = console.warn;
  console.warn = (message, ...optionalParams) => !(typeof message === "string" && re.test(message)) && _warn(message, ...optionalParams);
  fn();
  console.warn = _warn;
}
function createSvelteNodeView(constructor, options) {
  return (node, view, getPos) => new SvelteNodeView(constructor, options, node, view, getPos);
}
var SvelteNodeView = class {
  constructor(constructor, options, node, view, getPos) {
    this.ignoreMutation = (m) => {
      if (m.type === "attributes")
        return true;
      if (this.isComponentUpdating)
        return true;
      const mutationIsInCeFalse = Array.from(this.dom.querySelectorAll("[contenteditable=false]")).find((e) => m.target == e || e.contains(m.target));
      if (mutationIsInCeFalse)
        return true;
      return false;
    };
    var _a;
    this.node = node;
    this.view = view;
    this.getPos = getPos;
    const target = document.createElement("div");
    const props = {
      attrs: node.attrs,
      contentDOM: (node2) => this.contentDOM = node2,
      rootDOM: (node2) => this.dom = node2,
      view,
      controls: {
        delete: () => this.deleteNode(),
        update: (cb) => {
          const tr = cb(this.view.state, node, getPos);
          this.view.dispatch(tr);
        }
      }
    };
    supressMissingPropWarnings(props, () => {
      this.component = new constructor({ target, props });
    });
    this.component.$$.before_update.push(() => this.isComponentUpdating = true);
    this.component.$$.after_update.push(() => {
      window.setTimeout(() => this.isComponentUpdating = false);
    });
    this.dom = (_a = this.dom) != null ? _a : target;
    this.dom.classList.add("svelte-node-view");
    this.dom.classList.add(`svelte-node-view--${options.name}`);
    const bindCallback = (attrs) => {
      this.node.attrs = attrs;
      const transaction = view.state.tr.setNodeMarkup(getPos(), null, attrs);
      view.dispatch(transaction);
    };
    const index = this.component.$$.props["attrs"];
    this.component.$$.bound[index] = bindCallback;
  }
  deleteNode() {
    const transaction = this.view.state.tr.delete(this.getPos(), this.getPos() + 1);
    this.view.dispatch(transaction);
  }
  stopEvent(e) {
    if (e instanceof DragEvent) {
      return false;
    }
    return true;
  }
};

// src/plugin.ts
var import_prosemirror_state = require("prosemirror-state");
function mapValues(obj, mapFn) {
  const entries = Object.entries(obj);
  const mappedEntries = entries.map(([key, val]) => [key, mapFn(val, key)]);
  return Object.fromEntries(mappedEntries);
}
var svelteNodeViewPlugin = (options) => {
  const nodeViews = mapValues(options.nodes, (ctor, name) => createSvelteNodeView(ctor, { name }));
  return new import_prosemirror_state.Plugin({
    key: new import_prosemirror_state.PluginKey("prosemirror-svelte"),
    props: { nodeViews }
  });
};
function svelteSchemaNode(tag, defaultData) {
  return {
    draggable: true,
    attrs: mapValues(defaultData, (v) => ({ default: v })),
    parseDOM: [{
      tag,
      getAttrs(dom) {
        return mapValues(defaultData, (_, attr) => JSON.parse(dom.getAttribute(`data-${attr}`)));
      }
    }],
    toDOM(node) {
      const mappedEntries = Object.entries(node.attrs).map(([key, val]) => [`data-${key}`, JSON.stringify(val)]);
      return [tag, Object.fromEntries(mappedEntries)];
    }
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  createSvelteNodeView,
  svelteNodeViewPlugin,
  svelteSchemaNode
});
